# psdist

This repository is a collection of analysis and visualization methods for six-dimensional position-momentum space (phase space) distributions. Its primary use has been to slice and project high-dimensional data, both in point-cloud and image form.


## Installation

https://pypi.org/project/psdist/


## Examples

See `/examples` folder and https://austin-hoover.github.io/psdist/.


## Related packages

* https://github.com/openPMD/openPMD-viewer
* https://github.com/bwheelz36/ParticlePhaseSpace
* https://github.com/ColwynGulliford/distgen
* https://aplpy.readthedocs.io/en/stable/fitsfigure/slicing.html